#! /usr/bin/env python
#
# Copyright INRA-URGI 2009-2010
# 
# This software is governed by the CeCILL license under French law and
# abiding by the rules of distribution of free software. You can use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
# 
# As a counterpart to the access to the source code and rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty and the software's author, the holder of the
# economic rights, and the successive licensors have only limited
# liability.
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading, using, modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean that it is complicated to manipulate, and that also
# therefore means that it is reserved for developers and experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and, more generally, to use and operate it in the
# same conditions as regards security.
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.
#
"""Modify the content of a FASTA file"""

from optparse import OptionParser
from commons.core.parsing.FastaParser import FastaParser
from commons.core.writer.FastaWriter import FastaWriter
from SMART.Java.Python.misc.Progress import Progress


if __name__ == "__main__":
    
    # parse command line
    description = "Modify Sequence List v1.0.1: Extend or shring a list of sequences. [Category: Data Modification]"

    parser = OptionParser(description = description)
    parser.add_option("-i", "--input",                     dest="inputFileName",    action="store",                                         type="string", help="input file [compulsory] [format: file in FASTA format]")
    parser.add_option("-o", "--output",                    dest="outputFileName", action="store",            default=None,    type="string", help="output file [compulsory] [format: output file in FASTA format]")
    parser.add_option("-s", "--start",                     dest="start",                    action="store",            default=None,    type="int",        help="keep first nucleotides [format: int]")
    parser.add_option("-e", "--end",                         dest="end",                        action="store",            default=None,    type="int",        help="keep last nucleotides [format: int]")
    parser.add_option("-v", "--verbosity",             dest="verbosity",            action="store",            default=1,         type="int",        help="trace level [format: int]")
    (options, args) = parser.parse_args()

    parser     = FastaParser(options.inputFileName, options.verbosity)
    writer     = FastaWriter(options.outputFileName, options.verbosity)
    progress = Progress(parser.getNbSequences(), "Reading file %s" % (options.inputFileName), options.verbosity)
    for sequence in parser.getIterator():
        if options.start != None:
            sequence.shrinkToFirstNucleotides(options.start)
        if options.end != None:
            sequence.shrinkToLastNucleotides(options.end)
        writer.addSequence(sequence)
        progress.inc()
    progress.done()
